# show_result.tcl

######################################################################
# Copyright 2000 Nokia IP, Inc.  All rights reserved.
#
# YOU MAY ONLY USE THE MATERIALS FOUND IN THIS FILE PURSUANT TO THE
# TERMS OF THE EVALUATION LICENSE AGREEMENT FOUND IN "/LICENSE".  ALL
# OTHER USES ARE EXPRESSLY PROHIBITED.
######################################################################
#
# $Id: show_result.tcl,v 1.14 2005/06/06 23:40:51 amatai Exp $
#

# this script has a routine that displays the results of "apply", etc.
# 

#********************************************************************
# Procedure   : show_result_item
# Description : displays a single message; detects a list within the list
# Arguments   : result_item ->	  an individual error message or a 
#				  list of messages
# Returns     : Nothing
# See also    :
#*******************************************************************/

proc show_result_item { result_item } {
    if { [string index $result_item 0] == "\{" } {
	foreach item $result_item {
	    show_result_item $item
	}
    } else {
	TEXT "$result_item"
	if { [string first "\n" $result_item] == -1 } {
	    HTML_BR
	}
     }
}

#********************************************************************
# Procedure   : show_result
# Description : displays either error messages or "Apply/Save successful"
#		delimited by the appropriate separators
# Arguments   : result ->	  result returned by "libdb set" call;
#				  used to determine whether the lines in
#			  	  err_list are Errors or Notifications;
#				  default is 1 (error)
#		t_max_messages -> number of messages to display;
#				  when number of messages in err_list
#				  is more than this number, the following
#				  line is output:
#				  (And more messages...);
#				  default is to view all messages
#		args -> additional messages to display with Apply/Save banner
# Returns     : Nothing
# See also    :
#*******************************************************************/

proc show_result { {result -1} {t_max_messages 0} args } {
    global err_list apply save Libdb_Result cerr_list
    global env		
    if {![info exists err_list]} {
        set err_list [list]
    }
    if {[info exists cerr_list]} {
        set err_list [concat $cerr_list $err_list]
    }

    if { $result == -1 } {
	set result $Libdb_Result
    }
    set msg_list [list]
    set bar_back_txt "-------------"
    if {[llength $err_list] > 0} {
	# if there are any errors, print them between red bars along with
	# any notices.
	if { $result == 1 } {
	    set bar_front "/images/errorbar.gif"
	    set bar_front_txt "-- Error ----"
	    set bar_back "/images/redbar.gif"
	} else {
	    set bar_front /images/msgbar.gif
	    set bar_front_txt "-- Notice ----"
	    set bar_back /images/bluebar.gif
	}
	# future: set msg_list [concat $err_list $notice_msg_list]
	set msg_list $err_list
    } else {
	# there were no messages
	set bar_front "/images/apply.gif"
	set bar_front_txt "-- Success ----"
	set bar_back "/images/greenbar.gif"
	if { [info exists save] == 1 && $save == 1 } {
        if {[info exists env(CLUSTER_ID)] } {
	       lappend msg_list "Save successful on all nodes in the cluster.\n"
		} else {
	       lappend msg_list "Save successful.\n"
	    }
	} elseif { [info exists apply] == 1 && $apply == 1 } {
        if {[info exists env(CLUSTER_ID)] } {
	        lappend msg_list "Apply successful on all nodes in the cluster.\n"
	    }  else {
	        lappend msg_list "Apply successful.\n"
	    }
	}
	if { [llength $args] > 0} {
	  set msg_list [concat $msg_list $args]
	}
    }

    # if there were any messages, print them between bars
    if {$msg_list != ""} {
	HTML_Image $bar_front $bar_front_txt
	HTML_BR
	if {[llength $msg_list] == 1} {
	    # A single message, just print it
	    set msg [lindex $msg_list 0]
	    show_result_item $msg
	} else {
	    # multiple messages, make a list
	    if {$t_max_messages > 0 && \
			[llength $msg_list] > $t_max_messages} {
		# There are so many messages, we only want to view the
		# first few.
		set msg_list [lrange $msg_list 0 \
			    [expr $t_max_messages - 2]]
		lappend msg_list "(And more messages...)\n"
	    }
	    foreach msg $msg_list {
		show_result_item $msg
	    }
	}
	HTML_Image $bar_back $bar_back_txt
	HTML_BR
    } 
}

